const {
    info
} = require('@vue/cli-shared-utils')
const ejs = require('ejs')
const fs = require('fs')
const copy = require('copy')
const resolve = require('resolve')
const path = require('path')
const chalk = require('chalk')
const inquirer = require('inquirer')
const baseDir = resolve.sync('vue-cli-plugin-ts-multi-pages', { basedir: process.cwd() })
const source = path.resolve(path.dirname(baseDir), 'generator/template/**')
module.exports = (api, opts)=>{
    api.registerCommand('add', {
        description: '创建一个新页面',
        usage: 'vue-cli-service add [page]',
    }, async function serve (args) {
        const entry = args._[0]
        if(entry){
            if(!fs.existsSync(api.resolve('./src/pages'))){
              fs.mkdirSync(api.resolve('./src/pages'))
            }
            const entryPath = api.resolve(`./src/pages/${entry}`)
            if( fs.existsSync(entryPath)){
                console.log(chalk.red(`${entry}页面已存在，请重新填写页面！`))
                return
            } 
            inquirer
            .prompt([
                {
                    type: 'input',
                    name: 'name',
                    message: '请输入页面的中文名称（选填）：'
                }
            ])
            .then(answers => {
              if(answers.name){
                copy(source, api.resolve(entryPath), function(err, files) {
                    if (err) throw err;
                    // 修改html 
                    modifyFile(`${entryPath}/index.html`,{title:answers.name},'string')
                    modifyFile(`${entryPath}/index.ts`,{name:entry})
                    modifyFile(`${entryPath}/views/App.vue`,{title:answers.name})
                    console.log(chalk.green(`页面${entry}创建成功！`))
                });
              }
            });
        } else {
            console.log(chalk.red(`npm run add [page] 缺少页面参数: page`))
        }

        /**
         * 修改文件
         * @param {*} file 
         * @param {*} data 
         */
        function modifyFile(file,data,type){
            if (fs.existsSync(file)) {
                const content = fs.readFileSync(file).toString();
                let result = content;
                if(type==='string'){
                    for (const dataItem of Object.keys(data)) {
                        const reg = new RegExp(`{{${dataItem}}}`,'g')
                        result = result.replace(reg,`${data[dataItem]}`);
                    }
                } else{
                    result = ejs.compile(content)(data);
                }
                fs.writeFileSync(file, result);
            }
        }
    })
}